Monty Python's Flying Circus: Just the Words - Episode 20

# Episode Twenty

'The Attila the Hun Show'
Attila the Nun
Secretary of State striptease
Vox pops on politicians
Ratcatcher
Wainscotting
Killer sheep
The news for parrots
The news for gibbons
Today in Parliament
The news for wombats
Attila the Bun
The Idiot in Society
Test match
The Epsom furniture race
'Take Your Pick'

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Stock film of fast moving Huns thundering around on horseback.
First Voice Over | In the fifth century, as the once-mighty Roman Empire crumbled, the soft underbelly of Western Europe lay invitingly exposed to the barbarian hordes to the East. Alaric the Visigoth, Galseric the Vandal and Theodoric the Ostrogoth in turn swept westward in a reign of terror. But none surpassed in power and cruelty the mighty Attila the Hun.
Second Voice Over | Ladies and gentlemen, it's the 'The Attila the Hun Show'.
| Cut to film. Music plays: 'The Debbie Reynolds Show' theme - 'With a little love, just a little love'. We see Attila the Hun running towards Mrs Attila the Hun in slow motion, laughing and smiling. CAPTION: 'THE ATTILA THE HUN SHOW' Attila and his wife frolic and fall over in slow motion for a bit (copying the Debbie Reynolds credits as closely as possible). CAPTIONS: 'STARRING ATTILA THE HUN' 'AND KAY SLUDGE AS MRS ATTILA THE HUN' 'WITH TY GUDRUN AND NIK CON AS JENNY AND ROBIN ATTILA THE HUN' 'MUSIC BY THE HUNLETS' Cut to stock film of fast-moving Huns on horseback.
First Voice Over | In the second quarter of the fifth century, the Huns became a byword for merciless savagery. Their Khan was the mighty warrior Attila. With his devastating armies he swept across Central Europe.
| Cut to American-living-room-type set. Doorbell rings. Attila the Hun enters the door.
Attila | Oh darling, I'm home.
Mrs Attila | Hello darling. Had a busy day at the office?
Attila | Not at all bad. (playing to camera) Another merciless sweep across Central Europe.
| Canned laughter.
Mrs Attila | I won't say I'm glad to see you, but boy, am I glad to see you.
| Enormous canned laughter and applause. Enter two kids.
Jenny | Hi, daddy.
Robin | Hi, daddy.
Attila | Hi, Jenny, hi, Robby. (brief canned applause) Hey, I've got a present for you two kids in that bag. (they pull out a severed head) I want you kids to get a-head.
| Enormous shriek of canned laughter and applause. Enter one of us blacked up like Rochester, holding a tray of drinks.
Uncle Tom | Hear you are, Mr Hun!
| Masses of dubbed applause.
Attila | Hi, Uncle Tom.
Uncle Tom | There's a whole horde of them marauding Visigoths to see y'all.
| Cut to more stock film of these Huns rushing about on their horses. Superimposed image of announcer at his desk.
Announcer | And now for something completely different.
It's Man | It's ...
| Massive canned applause. Animated credit titles.
| At the end of these titles cut to a country road. After three seconds a motorbike appears in the distance and speeds towards the camera. We see that a wild-looking nun is riding it.
First Voice Over | Yes, it's Attila the Nun.
| Attila the Nun flashes past the camera, There is a loud sound of the bike crashing off camera.
Second Voice Over | A simple country girl who took a vow of eternal brutality.
| Attila the Nun on a hospital bed, struggling wildly with two doctors and a nurse who are trying to hold her down. She looks really fearsome. Another doctor enters and summons the nurse away.
Doctor | Nurse!
| The camera tracks away and comes up on another bed in which is sitting a beautiful girl revealing more than a patient normally would and endowed with Carol's . . . undoubted attributes. Screens are placed around her. The doctor and nurse come in through the screens.
Doctor | Hello, Miss Norris. How are you?
Miss Norris | Not too bad, thank you, doctor.
Doctor | Yes, well I think I'd better examine you.
| Cut to a line of half a dozen shabby men in filthy macs down to the floor and caps, who shuffle in through the screens and stand at the foot of the bed leering.
Miss Norris | What are they doing here?
Doctor | It's all right, they're students. Um... lights please, nurse. (a single red spotlight spills down on the girl; cut back to the men leering) Oh... and... er... music, too. (nurse presses a switch beside bed; stripper music; very loud; cut to line of men getting very exalted - hands deep in pockets) Breathe in ... out ... in ... out...
| After about five seconds the music reaches a climax and ends. The men in macs all applaud.
| Cut to reverse angle to show that we are no longer in a hospital but in a seedy strip club. The curtains have just swished shut.
Compère | Thank you, thank you. Charles Crompton, the Stripping Doctor. And next, gentlemen and ladies, here at the Peephole Club for the very first time - a very big welcome please for the Secretary of State for Commonwealth Affairs.
| Curtains open. The compère leaves the stage. A man in city gent's outfit walks into the spotlight.
Minister | Good evening. Tonight I'd like to restate our position on agricultural subsidies, (soft breathy jazzy music creeps in behind his words and he starts to strip as he talks) and their effect on our Commonwealth relationships. Now although we believe, theoretically, in ending guaranteed farm prices, we also believe in the need for a corresponding import levy to maintain consumer prices at a realistic level. But this would have the effect of consolidating our gains of the previous fiscal year, prior to the entry. But I pledge that should we join the Common Market - even maintaining the present position on subsidies - we will never jeopardize, we will never compromise our unique relationship with the Commonwealth countries. A prices structure related to any import charges will be systematically adjusted to the particular requirements of our Commonwealth partners (he has now removed all his clothes apart from a tassel on each nipple and one on the front of some skin-tight briefs; he starts to revolve the tassels on his nipples) - so that together we will maintain a positive, and mutually beneficial alliance in world trade (he turns revealing a tassle on each buttock which he also revolves) and for world peace. Thank you and goodnight.
| He removes the last tassle from his G-string with a flourish. Blackout and curtains quickly close. Compère bounces back on stage.
Compère | Wasn't he marvellous? The Secretary of State for Commonwealth Affairs! And now gentlemen and ladies, a very big welcome please for the Minister of Pensions and Social Security!
| Burst of Turkish music and curtains swish back as another bowler-hatted pinstriped minister enters doing a Turkish dance. Cut to still of Houses of Parliament. Slow track in. Music changes to impressive patriotic music.
Voice Over | Yes, today in Britain there is a new wave of interest in politics and politicians.
| Cut to vox pops outside Houses of Parliament. CAPTION: 'A GROUPIE'
First Girl | Well, we're just in it for the lobbying, you know. We just love lobbying.
Second Girl | And the debates - you know a good debate ... is just... fabulous.
Third Girl | Well, I've been going with ministers for five years now and, you know... I think they're wonderful.
Fourth Girl | Oh yes, I like civil servants.
Third Girl | Oh yes, they're nice.
Fifth Girl | I like the Speaker.
Fourth Girl | Oh yes.
Second Girl | I like Black Rod.
Voice Over | What do their parents think?
| Cut to suburban house. Mr Concrete standing in front of door of outside loo.
Mr Concrete | Well she's broken our hearts, the little bastard. She's been nothing but trouble and if she comes round here again I'll kick her teeth in.
| He turns and goes in. Cut to interior: the Concrete's sitting room. Mrs Concrete is sitting on the sofa, knitting. Mr Concrete enters.
Mrs Concrete | Have you been talking to television again, dear?
Mr Concrete | Yes, I bloody told 'em.
Mrs Concrete | What about?
Mr Concrete | I dunno.
Mrs Concrete | Was it Reginald Bosanquet?
Mr Concrete | No, no, no.
Mrs Concrete | Did he have his head all bandaged?
Mr Concrete | No, it wasn't like that. They had lots of lights and cameras and tape recorders and all that sort of thing.
Mrs Concrete | Oh, that'll be Ray Baxter and the boys and girls from 'Tomorrow's World'. Oh, I prefer Reginald Bosanquet, there's not so many of them. (the doorbell rings) Oh - that'll be the ratcatcher. (she lets the ratcatcher in)
Ratcatcher | Hello - Mr and Mrs Concrete?
Both | Yes.
Ratcatcher | Well, well, well, well, well, well, well, well, well, well, well, how very nice. Allow me to introduce myself. I am Leslie Ames, the Chairman of the Test Selection Committee, and I'm very pleased to be able to tell you that your flat has been chosen as the venue for the third test against the West Indies.
Mrs Concrete | Really?
Ratcatcher | No, it was just a little joke. Actually, I am the Council Ratcatcher.
Mrs Concrete | Oh yes, we've been expecting you.
Ratcatcher | Oh, I gather you've got a little rodental problem.
Mrs Concrete | Oh, blimey. You'd think he was awake all the night, scrabbling down by the wainscotting.
Ratcatcher | Um, that's an interesting word, isn't it?
Mrs Concrete | What?
Ratcatcher | Wainscotting ... Wainscotting ... Wainscotting ... sounds like a little Dorset village, doesn't it? Wainscotting.
| Cut to the village of Wains Cotting. A woman rushes out of a house.
Woman | We've been mentioned on telly!
| Cut back to Concretes' house.
Ratcatcher | Now, where is it worst?
Mrs Concrete | Well, down here. You can usually hear them.
| Indicates base of wall, which has a label on it saying 'Wainscotting'.
Ratcatcher | Sssssh
Voice Over | Baa ... baa ... baa ... baa ... baa ... baa...
Ratcatcher | No, that's sheep you've got there.
Voice Over | Baa ... baa.
Ratcatcher | No, that's definitely sheep. A bit of a puzzle, really.
Mrs Concrete | Is it?
Ratcatcher | Yeah, well, I mean it's (a) not going to respond to a nice piece of cheese and (b) it isn't going to fit into a trap.
Mrs Concrete | Oh - what are you going to do?
Ratcatcher | Well, we'll have to look for the hole.
| We follow them as they look along the wainscotting.
Mrs Concrete | Oh yeah. There's one here.
| She indicates a small black mousehole.
Ratcatcher | No, no, that's mice.
| He reaches in and pulls out a line of mice strung out on a piece of elastic. Then he lets go so they shoot in again. The ratcatcher moves on. He moves a chair, behind which there is a three-foot-high black hole.
Ratcatcher | Ah, this is what we're after.
| The baa-ings get louder. At this point six cricketers enter the room.
Cricketer | Excuse me, is the third test in here?
Mr Concrete | No - that was a joke - a joke!
Cricketer | Oh blimey, (exeunt)
Ratcatcher | Right. Well, I'm going in the wainscotting.
| Cut to 'Wains Cotting' woman, who rushes out again.
Woman | They said it again.
| Back to the sitting room.
Ratcatcher | I'm going to lay down some sheep poison.
| He disappears into the hole. We hear:
Voice Over | Baa, baa, baa.
| A gunshot. The ratcatcher reappears clutching his arm.
Ratcatcher | Aagh. Ooh! It's got a gun!
Mrs Concrete | Blimey.
Ratcatcher | Now, normally a sheep is a placid, timid creature, but you've got a killer.
| Poster: 'Wanted For Armed Robbery - Basil' with a picture of a sheep. Exciting crime-type music. Mix through to newspaper headlines: 'Farmers Ambushed in Pen', 'Merino Ram in Wages Grab'. Eerie science fiction music; mix through to a laboratory. A scientist looking through microscope and his busty attractive assistant.
Professor | It's an entirely new strain of sheep, a killer sheep that can not only hold a rifle but is also a first-class shot.
Assistant | But where are they coming from, professor?
Professor | That I don't know. I just don't know. I really just don't know. I'm afraid I really just don't know. I'm afraid even I really just don't know. I have to tell you I'm afraid even I really just don't know. I'm afraid I have to tell you... (she hands him a glass of water which she had been busy getting as soon as he started into this speech) ... thank you ... (resuming normal breezy voice) ... I don't know. Our only clue is this portion of wolf's clothing which the killer sheep ...
| Cut to Viking.
Viking | ... was wearing...
| Cut back to sketch.
Professor | ... in yesterday's raid on Selfridges.
Assistant | I'll carry out tests on it straight away, professor.
| She opens a door to another lab; but it is full of cricketers.
Cricketer | Hello, is the third test in here, please?
| She slams the door on them.
Assistant | Professor, there are some cricketers in the laboratory.
Professor | This may be even more serious than even I had at first been imagining. What a strange... strange line. There's no time to waste. Get me the Chief Commissioner of Police.
Assistant | Yes, sir!
| She opens a cupboard and slides out the Chief Commissioner of Police on a sort of slab. He grins and waves cheerily. 'This is Your Life' music and applause.
Professor | No, no, on the phone.
Assistant | Oh... (she pushes him back in)
Professor | Look of fear! (he is staring transfixed at something in the doorway) Another strange line. Look out, Miss Garter Oil!
Assistant | Professor! What is it? What have you seen?
Professor | Look - there, in the doorway.
| Cut to doorway: through it is animation of a huge sheep with an eye patch.
Assistant | Urghhh! Arthur X! Leader of the Pennine Gang!
| ANIMATION: perhaps even mixed with stock film - as the fevered mind of Gilliam takes it - sheep armed to the teeth, sheep executing dangerous raids, Basil Cassidy and the Sundance Sheep, sheep with machine gun coming out of its arse etc. At the end of the animation, cut to studio. A narrator sitting in what could be a news set at a desk.
Narrator | But soon the killer sheep began to infect other animals with its startling intelligence. Pussy cats began to arrange mortgages, cocker spaniels began to design supermarkets...
| Cut back to the aninmation again: a parrot.
Parrot | And parrots started to announce television programmes. It's 8 o'clock and time for the News.
Narrator | Good evening. Here is the news for Parrots. No parrots were involved in an accident on the M1 today when a lorry carrying high-octane fuel was in collison with a bollard. That's a bollard and not a parrot. A spokesman for parrots said he was glad no parrots were involved. The Minister of Technology (photo of minister with parrot on his shoulder) today met the three Russian leaders (cut to photograph of Brezhnev, Podgorny and Kosygin all in a group and each with a parrot on his shoulder) to discuss a £4 million airliner deal...(cut back to narrator) None of them went in the cage, or swung on the little wooden trapeze or ate any of the nice millet seed yum, yum. That's the end of the news, now our program for parrots continues with part three of 'A Tale of Two Cities', specially adapted for parrots by Joey Boy. The story so far, Dr. Manette is in England after eighteen years (as he speaks French Revolution type music creeps in under his words) in the Bastille. His daughter Lucy awaits her lover Charles Darney, who we have just learned is in fact the nephew of the Marquis de St Evremond, whose cruelty had placed Manette in the Bastille. Darney arrives to find Lucy tending her aged father.
| SUPERIMPOSED CAPTION: 'LONDON 1793' Music reaches a climax and we mix slowly through to an eighteenth-century living room. Lucy is nursing her father. Some low music continues over. Suddenly the door bursts open and Charles Darnay enters.
Darnay | (in parrot voice) 'Allo, 'allo.
Lucy | 'Allo, 'allo, 'allo.
Old Man | 'Allo, 'allo, 'allo.
Darnay | Who's a pretty boy, then?
Lucy | 'Allo, 'allo, 'allo.
| And more of the same. Cut back to the narrator.
Narrator | And while that's going on, here is the news for gibbons. No gibbons were involved in...
| The narrator's voice fade.
Voice Over | And while that's going on, here from Westminster is a parliamentary report for Humans.
Cyril | In the debate, a spokesman accused the goverment of being silly and doing not at all good things. The member accepted this in the spirit of healthy criticism, but denied that he had ever been naughty with a choir boy. Angry shouts of 'What about the Watermelon then?' were ordered then by the speaker to be stricken from the record and put into a brown paper bag in the lavvy. Any further interruptions would be cut up and distributed amongst the poor. For the Government, a front-bench spokesman said the Agricultural Tariff would have to be raised, and he fancied a bit. Futhermore, he argued, this would give a large boost to farmers, him, his friends, and Miss Moist of Knightsbridge. From the back benches there were opposition shouts of 'Postcards for sale' and a healthy cry of 'Who likes a sailor then?' from the minister without portfolio. Replying, the Shadow Minister said he could no longer deny the rumors, but he and the Dachshund were very happy. And in any case he argued Rhubarb was cheap, and what was the harm in a sauna bath?
| Cut to original narrator. CAPTION: '7 Hours Later'
Narrator | ...were not involved. The Minister of Technology (cut to photograph of minister with a wombat on his shoulder) met the three Russian leaders (Russian leaders again all with wombats on their shoulders) today to discuss a £4 million airliner deal....none of them were indigenous to Australia, carried their young in pouches, or ate any of those yummy Eucalyptus leaves.Yum Yum. Thats the news for wombats, and now Attila the Bun!
| ANIMATION: a vicious rampaging bun.
Voice Over | Well that's all for Attila the Bun, and now - idiots!
| A village idiot in smock and straw hat, red cheeks, straw in mouth, sitting on a wall, making funny noises and rolling his eyes.
Voice Over | Arthur Figgis is an idiot. A village idiot. Tonight we look at the idiot in society.
| Cut to close-up of Figgis talking to camera. Very big close-up losing the top and bottom of his head.
Figgis | (educated voice) Well I feel very keenly that the idiot is a part of the old village system, and as such has a vital role to play in a modern rural society, because you see ... (suddenly switches to rural accent) ooh ar ooh ar before the crops go gey are in the medley crun and the birds slides nightly on the oor ar ... (vicar passes and gives him sixpence) Ooh ar thankee, Vicar ... (educated voice) There is this very real need in society for someone whom almost anyone can look down on and ridicule. And this is the role that ... ooh ar naggy gamly rangle tandie oogly noogle Goblie oog ... (passing lady gives him sixpence) Thank you, Mrs Thompson... this is the role that I and members of my family have fulfilled in this village for the past four hundred years... Good morning, Mr Jenkins, ICI have increased their half-yearly dividend, I see.
| We see Mr Jenkins pass, he is also an idiot, identically dressed.
Mr Jenkins | Yes, splendid.
Figgis | That's Mr Jenkins - he's another idiot. And so you see the idiot does provide a vital psycho-social service for this community. Oh, excuse me, a coach party has just arrived. I shall have to fall off the wall, I'm afraid.
| He falls backwards off the wall. Cut to Figgins in idiot's costume coming out of a suburban home. He walks on to the lawn on which are several pieces of gym equipment. He runs head-on into horse (speeded up) and falls over, concussed.
Voice Over | Arthur takes idiotting seriously. He is up at six o'clock every morning working on special training equipment designed to keep him silly. And of course he takes great pride in his appearance.
| Figgis, dressed in nice clean smock, jumps into a pond. He immediately scrambles up, pulls out a mirror and pats mud an his face critically, as if making-up.
Voice Over | Like the doctor, the blacksmith, the carpenter, Mr Figgis is an important figure in this village and - like them - he uses the local bank.
| Village square. A bank. Figgis is walking towards it. People giggling and pointing. He goes into a silly routine. Figgis enters the bank. Cut to bank manager standing outside bank. CAPTION: 'M. BRANDO - BANK MANAGER'
Bank Manager | Yes, we have quite a number of idiots banking here.
Voice Over | What kind of money is there in idioting?
Manager | Well nowadays a really blithering idiot can make anything up to ten thousand pounds a year - if he's the head of some big industrial combine. But of course, the more old-fashioned idiot still refuses to take money.
| We see Figgis handing over a cheque to cashier; cashier pushes across a pile of moss, pebbles, bits of wood and acorns.
Manager | (voice over) He takes bits of string, wood, dead budgerigars, sparrows, anything, but it does make the cashier's job very difficult; but of course they're fools to themselves because the rate of interest over ten years on a piece of moss or a dead vole is almost negligible.
| A clerk appears at door of bank.
Clerk | Mr Brando.
Manager | Yes?
Clerk | Hollywood on the phone.
Manager | I'll take it in the office.
| Cut to a woodland glade.
Voice Over | But Mr Figgis is no ordinary idiot. He is a lecturer in idiocy at the University of East Anglia. Here he is taking a class of third-year students.
| Half a dozen loonies led by Figgis come dancing through the glade singing tunelessly. They are wearing long University scarves.
Voice Over | After three years of study these apprentice idiots receive a diploma of idiocy, a handful of mud and a kick on the head.
| A vice-chancellor stands in a University setting with some young idiots in front of him. They wear idiot gear with BA hoods. One walks forward to him, he gets a diploma, a faceful of mud and stoops to receive his kick on the head. Cut to happy parents smiling proudly.
Voice Over | But some of the older idiots resent the graduate idiot.
Old Idiot | I'm a completely self-taught idiot. I mean, ooh arh, nob arhh, nob arhh .... nobody does that anymore. Anybody who did that round here would be laughed off the street. No, nowadays people want something wittier.
| Wife empties breakfast over him. Cut to idiot falling repeatedly off a wall.
Voice Over | Kevin O'Nassis works largely with walls.
Kevin | (voice over) You've got to know what you're doing. I mean, some people think I'm mad. The villagers say I'm mad, the tourists say I'm mad, well I am mad, but I'm naturally mad. I don't use any chemicals.
Voice Over | But what of the idiot's private life? How about his relationship with women?
| Idiot in bed. Pull back to reveal he shares it with two very young, thin, nude girls.
Idiot | Well I may be an idiot but I'm no fool.
Voice Over | But the village idiot's dirty smock and wall-falling are a far cry from the modern world of the urban idiot. (stock film of city gents in their own clothes pouring out of trains) What kinds of backgrounds do these city idiots come from?
| Vox pops film of city gents. Subtitles explain their exaggerated accents.
First City Idiot | Eton, Sandhurst and the Guards, ha, ha, ha, ha.
Second City Idiot | I can't remember but I've got it written down some where.
Third City Idiot | Daddy's a banker. He needed a wastepaper basket.
Fourth City Idiot | Father was Home Secretary and mother won the Derby.
| Cut to a commentator with mike in close-up. Pull back in his speech, to discover he is standing in front of the main gate at Lords cricket ground.
Interviewer | The headquarters of these urban idiots is here in St John's Wood. Inside they can enjoy the company of other idiots and watch special performances of ritual idioting.
| Cut to quick wide-shot of cricket match being played at Lords. Cut to five terribly old idiots watching.
First Idiot | Well left.
Second Idiot | Well played.
Third Idiot | Well well.
Fourth Idiot | Well bred.
Fifth Idiot | (dies) Ah!
| Another very quick wide-shot of Lords. There is nothing at all happening and we can't distinguish anyone. Cut to three TV commentators in modern box, with sliding window open. They are surrounded by bottles.
Jim | Good afternoon and welcome to Lords on the second day of the first test. So far today we've had five hours batting from England and already they're nought for nought. Cowdrey is not out nought. Naughton is not in. Knott is in and is nought for not out. Naughton of Northants got a nasty knock on the nut in the nets last night but it's nothing of note. Next in is Nat Newton of Notts. Not Nutring - Nutting's at nine, er, Nutring knocked neatie nighty knock knock...(another commentator nudges him) ... anyway England have played extremely well for nothing, not a sausage, in reply to Iceland's first innings total of 722 for 2 declared, scored yesterday disappointingly fast in only twenty-one overs with lots of wild slogging and boundaries and all sorts of rubbishy things. But the main thing is that England have made an absolutely outstanding start so far, Peter?
Peter | Splendid. Just listen to those thighs. And now it's the North East's turn with the Samba. Brian.
Brian | (he has an enormous nose) Rather. (opens book) I'm reminded of the story of Gubby Allen in '32. ..
Jim | Oh, shut up or we'll close the bar. And now Bo Wildeburg is running up to bowl to Cowdrey, he runs up, he bowls to Cowdrey...
| Cut to fast bowler. He bowls the ball but the batsman makes no move whatsoever. The ball passes the off stump.
Jim | ... and no shot at all. Extremely well not played there.
Peter | Yes, beautifully not done anything about.
Brian | A superb shot of no kind whatsoever. I well remember Plum Warner leaving a very similar ball alone in 1732.
Jim | Oh shut up, long nose. Peter falls off his chair. And now it's Bo Wildeburg running in again to bowl to Cowdrey, he runs in. (bowler bowls us before; ball goes by as before) He bowls to Cowdrey - and no shot at all, a superb display of inertia there... And that's the end of the over, and drinks.
Peter | Gin and tonic please.
Jim | No, no the players are having drinks. And now, what's happening? I think Cowdrey's being taken off. (Two men in white coats, a la furniture removers, so maybe they're brown coats, are carrying the batsman off. Two men pass them with a green Chesterfield sofa making for the wicket.) Yes, Cowdrey is being carried off. Well I never. Now who's in next, it should be number three, Natt Newton of Notts... get your hand off my thigh, West... no I don't think it is... I think it's er, it's the sofa ... no it's the Chesterfield! The green Chesterfield is coming in at number three to take guard now.
Brian | I well remember a similar divan being brought on at Headingley in 9 BC against the darkies.
Jim | Oh, shut up, elephant snout. And now the green Chesterfield has taken guard and Iceland are putting on their spin dryer to bowl.
| Furniture fielding. The whole pitch is laid out with bits of furniture in correct positions. Three chairs in the slips; easy chair keeping wicket; bidet at mid on; TV set at cover; bookcase at mid off; roll-top writing desk at square leg; radiator at mid wicket etc. The spin dryer moves forward and bowls a real ball with its snozzle to a table, which is at the batting end with cricket pads on. It hits the table on the pad. Appeal.
Jim | The spin dryer moves back to his mark, it runs out to the wicket, bowls to the table... a little bit short but it's coming in a bit there and it's hit him on the pad... and the table is out, leg before wicket. That is England nought for one.
Different Voice Over | And now we leave Lords and go over to Epsom for the three o'clock.
| Cut to a race course. Furniture comes into shot racing the last fifty yards to the finishing post.
Commentator | Well here at Epsom we take up the running with fifty yards of this mile and a half race to go and it's the wash basin in the lead from WC Pedestal. Tucked in nicely there is the sofa going very well with Joanna Southcott's box making a good run from hat stand on the rails, and the standard lamp is failing fast but it's wash basin definitely taking up the running now being strongly pressed by ... At the post it's the wash basin from WC then sofa, hat stand, standard lamp and lastly Joanna Southcott's box.
| Cut to three bishops shouting from actual studio audience.
Bishops | Open the box! Open the box! Open the box! Open the box! Open the box!
| A simple 'Take Your Pick' style set with Michael Miles grinning type monster standing at centre of it.
Michael Miles | And could we have the next contender, please? (a pepperpot walks out onto the set towards Michael Miles) Ha ha ha... Good evening, madam, and your name is?
Woman | Yes, yes...
Michael Miles | And what's your name?
Woman | I go to church regularly.
Michael Miles | Jolly good, I see, and which prize do you have particular eyes on this evening?
Woman | I'd like the blow on the head.
Michael Miles | The blow on the head.
Woman | Just there. (points to the back of her head)
Michael Miles | Jolly good. Well your first question for the blow on the head this evening is: What great opponent of Cartesian dualism resists the reduction of psychological phenomena to physical states?
Woman | I don't know that!
Michael Miles | Well, have a guess.
Woman | Henri Bergson.
Michael Miles | Is the correct answer!
Woman | Ooh, that was lucky. I never even heard of him.
Michael Miles | Jolly good.
Woman | I don't like darkies.
Michael Miles | Ha ha ha. Who does? And now your second question for the blow on the head is: What is the main food that penguins eat?
Woman | Pork luncheon meat.
Michael Miles | No.
Woman | Spam?
Michael Miles | No, no, no. What do penguins eat? Penguins.
Woman | Penguins?
Michael Miles | Yes.
Woman | I hate penguins.
Michael Miles | No, no, no.
Woman | They eat themselves.
Michael Miles | No, no, what do penguins eat?
Woman | Horses! ... Armchairs!
Michael Miles | No, no, no. What do penguins eat?
Woman | Oh, penguins.
Michael Miles | Penguins.
Woman | Cannelloni.
Michael Miles | No.
Woman | Lasagna, moussaka, lobster thermidor, escalopes de veau à l'estragon avec endives gratinéed with cheese.
Michael Miles | No, no, no, no. I'll give you a clue. (mimes a fish swimming)
Woman | Ah! Brian Close.
Michael Miles | No. no.
Woman | Brian Inglis, Brian Johnson, Bryan Forbes.
Michael Miles | No, no!
Woman | Nanette Newman.
Michael Miles | No. What swims in the sea and gets caught in nets?
Woman | Henri Bergson.
Michael Miles | No.
Woman | Goats. Underwater goats with snorkels and flippers.
Michael Miles | No, no.
Woman | A buffalo with an aqualung.
Michael Miles | No, no.
Woman | Reginald Maudling.
Michael Miles | Yes, that's near enough. I'll give you that. Right, now, Mrs Scum, you have won your prize, do you still want the blow on the head?
Woman | Yes, yes.
Michael Miles | I'll offer you a poke in the eye.
Woman | No! I want a blow on the head.
Michael Miles | A punch in the throat?
Woman | No.
Michael Miles | All right then, a kick in the kneecap?
Woman | No.
Michael Miles | Mrs Scum, I'm offering you a boot in the teeth and a dagger up the strap?
Woman | Er...
Voices | Blow on the head! Take the blow on the head!
Woman | No, no. I'll take the blow on the head.
Michael Miles | Very well then, Mrs Scum, you have won tonight's star prize, the blow on the head.
| He strikes her on head with an enormous mallet and she falls unconscious. A sexily dressed hostess in the background (Graham) strikes a small gong. The three bishops rush in and jump on her. Cut to sign: LICENCE FEES FROM 1ST JANUARY 1969 COLOUR TV AND RADIO £11-0-0 TV AND RADIO £6-0-0 RADIO ONLY £1-5-0 Roll credits over. CAPTION: THE END